@@ -8,15 +8,22 @@ import sys
 from collections import deque
 from functools import partial
 from multiprocessing import Pool
-from typing import Dict, Union, List
+from typing import Dict, List, Union
 
 import numpy as np
-from pymatgen.core import Molecule, Element
 from pymatgen.analysis.local_env import NearNeighbors
+from pymatgen.core import Element, Molecule
 from pymatgen.io.babel import BabelMolAdaptor
 
-from megnet.data.graph import StructureGraph, GaussianDistance, BaseGraphBatchGenerator, GraphBatchGenerator, Converter
+from megnet.data.graph import (
+    BaseGraphBatchGenerator,
+    Converter,
+    GaussianDistance,
+    GraphBatchGenerator,
+    StructureGraph,
+)
 from megnet.utils.general import fast_label_binarize
+
 from .qm9 import ring_to_vector
 
 try:
@@ -150,9 +157,9 @@ class MolecularGraph(StructureGraph):
 
         # Check if all feature names are valid
         if any(i not in _ATOM_FEATURES for i in atom_features):
-            bad_features = set(atom_features).difference(_ATOM_FEATURES)
+            bad_features = set(atom_features).difference(_ATOM_FEATURES)  # type: ignore
             raise ValueError(f"Unrecognized atom features: {', '.join(bad_features)}")
-        self.atom_features = atom_features
+        self.atom_features = atom_features  # type: ignore
         if any(i not in _BOND_FEATURES for i in bond_features):
             bad_features = set(bond_features).difference(_BOND_FEATURES)
             raise ValueError(f"Unrecognized bond features: {', '.join(bad_features)}")
@@ -502,7 +509,7 @@ def mol_from_file(file_path: str, file_format: str = "xyz"):
         file_path(str)
         file_format(str): allow formats that open babel supports
     """
-    mol = list(pybel.readfile(format=file_format, filename=file_path))[0]
+    mol = list(pybel.readfile(format=file_format, filename=file_path))[0]  # type: ignore
     return mol
 
 
