@@ -1,15 +1,21 @@
-import tensorflow as tf
-import unittest
-import os
 import json
+import os
+import unittest
 
-from megnet.data.molecule import SimpleMolGraph
-from megnet.data.graph import DummyConverter
-from megnet.utils.general import to_list
-from pymatgen.core import Molecule
 import numpy as np
+import tensorflow as tf
+from pymatgen.core import Molecule
 
-from megnet.data.molecule import MolecularGraph, MolecularGraphBatchGenerator, pybel, mol_from_smiles, ring_to_vector
+from megnet.data.graph import DummyConverter
+from megnet.data.molecule import (
+    MolecularGraph,
+    MolecularGraphBatchGenerator,
+    SimpleMolGraph,
+    mol_from_smiles,
+    pybel,
+    ring_to_vector,
+)
+from megnet.utils.general import to_list
 
 if pybel is None:
     import_failed = True
