@@ -9,8 +9,8 @@ from tensorflow.keras.layers import deserialize as keras_layer_deserialize
 
 from megnet.activations import softplus2, swish
 from megnet.layers.featurizer import GaussianExpansion
-from megnet.layers.graph import MEGNetLayer, CrystalGraphLayer, InteractionLayer
-from megnet.layers.readout import Set2Set, LinearWithIndex
+from megnet.layers.graph import CrystalGraphLayer, InteractionLayer, MEGNetLayer
+from megnet.layers.readout import LinearWithIndex, Set2Set
 from megnet.losses import mean_squared_error_with_scale
 
 _CUSTOM_OBJECTS = globals()
