@@ -1,6 +1,8 @@
-import tensorflow as tf
 import unittest
-from pymatgen.core import Structure, Lattice
+
+import tensorflow as tf
+from pymatgen.core import Lattice, Structure
+
 from megnet.utils.data import get_graphs_within_cutoff
 
 
