@@ -1,8 +1,9 @@
-import tensorflow as tf
 import unittest
-from megnet.utils.layer import repeat_with_index, _repeat
+
 import tensorflow as tf
 
+from megnet.utils.layer import _repeat, repeat_with_index
+
 
 class TestCase(unittest.TestCase):
     @classmethod
